@@ -77,8 +77,13 @@ schemes = {
     },
     'Yandex Market user profile': {
         'flags': ['MarketNode', '{"entity":"user"'],
-        'regex': r'{"user":({"entity":"user".+?}),"isEmptyList',
+        'regex': r'type="application/json">({"widgets":{"@MarketNode/UserReviews".+?)</script>',
         'extract_json': True,
+        'transforms': [
+            json.loads,
+            lambda x: list(x['collections']['user'].values())[0],
+            json.dumps,
+        ],
         'fields': {
             'username': lambda x: x.get('login'),
             'yandex_uid': lambda x: x.get('uid'),
@@ -647,6 +652,27 @@ schemes = {
             'googleplus_uid': lambda x: x['profile']['socialMedia'].get('googleplus'),
         }
     },
+    'Google Document API': {
+        'flags': ['alternateLink', 'copyRequiresWriterPermission'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'url_mutations': [
+            {
+                # credits: https://github.com/Malfrats/xeuledoc
+                'from': r'https://(docs|drive).google.com/(spreadsheets|document|presentation|drawings|file)/d/(?P<gdoc_id>[\w-]+)',
+                'to': 'https://clients6.google.com/drive/v2beta/files/{gdoc_id}?fields=alternateLink%2CcopyRequiresWriterPermission%2CcreatedDate%2Cdescription%2CdriveId%2CfileSize%2CiconLink%2Cid%2Clabels(starred%2C%20trashed)%2ClastViewedByMeDate%2CmodifiedDate%2Cshared%2CteamDriveId%2CuserPermission(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cpermissions(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cparents(id)%2Ccapabilities(canMoveItemWithinDrive%2CcanMoveItemOutOfDrive%2CcanMoveItemOutOfTeamDrive%2CcanAddChildren%2CcanEdit%2CcanDownload%2CcanComment%2CcanMoveChildrenWithinDrive%2CcanRename%2CcanRemoveChildren%2CcanMoveItemIntoTeamDrive)%2Ckind&supportsTeamDrives=true&enforceSingleParent=true&key=AIzaSyC1eQ1xj69IdTMeii5r7brs3R90eck-m7k',
+                'headers': {"X-Origin": "https://drive.google.com"},
+            }
+        ],
+        'fields': {
+            'created_at': lambda x: x.get('createdDate'),
+            'updated_at': lambda x: x.get('modifiedDate'),
+            'gaia_id': lambda x: x.get('permissions')[1]['id'],
+            'fullname': lambda x: x.get('permissions')[1]['name'],
+            'email': lambda x: x.get('permissions')[1]['emailAddress'],
+            'image': lambda x: x.get('permissions')[1]['photoLink'],
+        }
+    },
     'Google Document': {
         'flags': ['_docs_flag_initialData'],
         'regex': r'({"docs-ails":"docs_\w+".+?});',
@@ -659,28 +685,7 @@ schemes = {
             'viewer_uid': lambda x: x['docs-pid'],
             'org_name': lambda x: x['docs-doddn'],
             'org_domain': lambda x: x['docs-dodn'],
-        }
-    },
-    'Google Document API': {
-        'flags': ['alternateLink', 'copyRequiresWriterPermission'],
-        'regex': r'^([\s\S]+)$',
-        'extract_json': True,
-        'url_mutations': [
-            {
-                # credits: https://github.com/Malfrats/xeuledoc
-                'from': r'https://docs.google.com/(spreadsheets|document|presentation|drawings)/d/(?P<gdoc_id>[\w-]+)',
-                'to': 'https://clients6.google.com/drive/v2beta/files/{gdoc_id}?fields=alternateLink%2CcopyRequiresWriterPermission%2CcreatedDate%2Cdescription%2CdriveId%2CfileSize%2CiconLink%2Cid%2Clabels(starred%2C%20trashed)%2ClastViewedByMeDate%2CmodifiedDate%2Cshared%2CteamDriveId%2CuserPermission(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cpermissions(id%2Cname%2CemailAddress%2Cdomain%2Crole%2CadditionalRoles%2CphotoLink%2Ctype%2CwithLink)%2Cparents(id)%2Ccapabilities(canMoveItemWithinDrive%2CcanMoveItemOutOfDrive%2CcanMoveItemOutOfTeamDrive%2CcanAddChildren%2CcanEdit%2CcanDownload%2CcanComment%2CcanMoveChildrenWithinDrive%2CcanRename%2CcanRemoveChildren%2CcanMoveItemIntoTeamDrive)%2Ckind&supportsTeamDrives=true&enforceSingleParent=true&key=AIzaSyC1eQ1xj69IdTMeii5r7brs3R90eck-m7k',
-                'headers': {"X-Origin": "https://drive.google.com"},
-            }
-        ],
-        'fields': {
-            'created_at': lambda x: x.get('createdDate'),
-            'updated_at': lambda x: x.get('modifiedDate'),
-            'owner_gaia_id': lambda x: x.get('permissions')[1]['id'],
-            'fullname': lambda x: x.get('permissions')[1]['name'],
-            'email': lambda x: x.get('permissions')[1]['emailAddress'],
-            'supposed_username': lambda x: x.get('permissions')[1]['emailAddress'].split('@')[0],
-            'image': lambda x: x.get('permissions')[1]['photoLink'],
+            'mime_type': lambda x: x.get('docs-dm'),
         }
     },
     'Google Maps contributions': {
@@ -1376,5 +1381,95 @@ schemes = {
             'gender': lambda x: x['sex'],
             'language': lambda x: x['lang'],
         }
-    }
+    },
+    'ICQ': {
+        'flags': ['a href="//icq.com/app" class="icq-prompt__banner-link"'],
+        'bs': True,
+        'fields': {
+            'fullname': lambda x: x.find('h2', {'class': 'icq-profile__name'}).contents[0],
+            'username': lambda x: x.find('p', {'class': 'icq-profile__subtitle'}).contents[0].strip('\n\t@'),
+            'bio': lambda x: x.find('p', {'class': 'icq-profile__description box'}).contents[0].strip('\n\t'),
+            'image': lambda x: x.find('meta', {'itemprop': 'image'}).get("content"),
+        }
+    },
+    'Pastebin': {
+        'flags': ['src="/themes/pastebin/js/'],
+        'bs': True,
+        'fields': {
+            'image': lambda x: 'https://pastebin.com' + x.find('div', {'class': 'user-icon'}).find('img').get('src'),
+            'website': lambda x: x.find('a', {'class': 'web'}).get('href'),
+            'location': lambda x: x.find('span', {'class': 'location'}).contents[0],
+            'views_count': lambda x: x.find('span', {'class': 'views'}).contents[0].replace(',', ''),
+            'all_views_count': lambda x: x.find('span', {'class': 'views -all'}).contents[0].replace(',', ''),
+            'created_at': lambda x: x.find('span', {'class': 'date-text'}).get("title"),
+        }
+    },
+    'Periscope': {
+        'flags': ['canonicalPeriscopeUrl', 'pscp://user/', 'property="og:site_name" content="Periscope"/>'],
+        'regex': r'data-store="(.*)"><div id="PageView"',
+        'extract_json': True,
+        'transforms': [
+            lambda x: x.replace('&quot;', '"'),
+            json.loads,
+            lambda x: list(x['UserCache']['users'].values())[0]['user'],
+            json.dumps,
+        ],
+        'fields': {
+            'id': lambda x: x['id'],
+            'created_at': lambda x: x['created_at'],
+            'periscope_username': lambda x: x['username'],
+            'fullname': lambda x: x['display_name'],
+            'bio': lambda x: x['description'], 
+            'follower_count': lambda x: x['n_followers'],
+            'following_count': lambda x: x['n_following'],
+            'hearts_count': lambda x: x['n_hearts'],
+            'is_beta_user': lambda x: x['is_beta_user'],
+            'is_employee': lambda x: x['is_employee'],
+            'isVerified': lambda x: x['isVerified'],
+            'is_twitter_verified': lambda x: x['is_twitter_verified'],
+            'twitterUserId': lambda x: x.get('twitterUserId'),
+            'twitter_screen_name': lambda x: x.get('twitter_screen_name'), 
+            'image': lambda x: x['profile_image_urls'][0]['url'],
+        }
+    },
+    'Imgur API': {
+        'flags': ['"reputation_count"', '"reputation_name"'],
+        'regex': r'^([\s\S]+)$',
+        'extract_json': True,
+        'url_mutations': [
+            {
+                'from': r'https?://imgur.com/user/(?P<username>[^/]+)',
+                'to': 'https://api.imgur.com/account/v1/accounts/{username}?client_id=546c25a59c58ad7',
+            }
+        ],
+        'fields': {
+            'id': lambda x: x['id'],
+            'imgur_username': lambda x: x['username'],
+            'bio': lambda x: x['bio'],
+            'reputation_count': lambda x: x['reputation_count'],
+            'reputation_name': lambda x: x['reputation_name'],
+            'image': lambda x: x['avatar_url'],
+            'created_at': lambda x: x['created_at'],
+        }
+    },
+    'PayPal': {
+        'flags': ["indexOf('qa.paypal.com')", 'PayPalSansSmall-Regular'],
+        'regex': r'application/json" id="client-data">(.*)</script><script type="application/json" id="l10n-content">',
+        'extract_json': True,       
+        'transforms': [
+            json.loads,
+            lambda x: x['recipientSlugDetails']['slugDetails'],
+            json.dumps,
+        ],
+        'fields': {
+            'fullname': lambda x: x['userInfo']['displayName'],
+            'alternative_fullname': lambda x: x['userInfo'].get('alternateFullName'),
+            'username': lambda x: x['paypalmeSlugName'],
+            'payerId': lambda x: x['payerId'],
+            'address': lambda x: x['userInfo']['displayAddress'],
+            'isProfileStatusActive': lambda x: x['isProfileStatusActive'],
+            'primaryCurrencyCode': lambda x: x['userInfo']['primaryCurrencyCode'],
+            'image': lambda x: x['userInfo']['profilePhotoUrl'],
+        }
+    },
 }
