@@ -2,7 +2,7 @@
 import pytest
 
 from socid_extractor.activation import get_twitter_headers
-from socid_extractor.main import parse, extract, HEADERS
+from socid_extractor.main import parse, extract, mutate_url, HEADERS
 
 
 def test_vk_user_profile_full():
@@ -269,10 +269,10 @@ def test_yandex_music_user_profile():
     assert info.get('username') == 'pritisk'
     assert info.get('name') == 'Юрий Притиск'
     assert info.get('image') == 'https://avatars.mds.yandex.net/get-yapic/29310/gK74BTyv8LrLRT0mQFIR2xcWv8-1/islands-200'
-    assert info.get('links') == '[]'
     assert info.get('is_verified') == 'False'
     assert info.get('liked_albums') == '0'
     assert info.get('liked_artists') == '0'
+    assert info.get('email') == 'pritisk@yandex.ru'
 
 
 @pytest.mark.skip(reason="failed from github CI infra IPs")
@@ -391,14 +391,27 @@ def test_500px():
     assert info.get('facebook_link') == 'www.facebook.com/the.maksimov'
 
 
-def test_google_documents_cookies():
-    cookies = open('google.test.cookies').read()
-    info = extract(
-        parse('https://docs.google.com/spreadsheets/d/1HtZKMLRXNsZ0HjtBmo0Gi03nUPiJIA4CC4jTYbCAnXw/edit#gid=0',
-              cookies)[0])
+def test_google_documents():
+    URL = 'https://docs.google.com/spreadsheets/d/1HtZKMLRXNsZ0HjtBmo0Gi03nUPiJIA4CC4jTYbCAnXw/edit#gid=0'
+    info = extract(parse(URL)[0])
 
-    assert info.get('org_domain') == 'breakoutcommerce.com'
     assert info.get('org_name') == 'Gooten'
+    assert info.get('mime_type') == 'application/vnd.google-apps.ritz'
+
+    mutated_url = mutate_url(URL)
+
+    assert len(mutated_url) == 1
+    url, add_headers = mutated_url[0]
+
+    info = extract(parse(url, headers=add_headers)[0])
+
+    assert info.get("created_at") == "2016-02-16T18:51:52.021Z"
+    assert info.get("updated_at") == "2019-10-23T17:15:47.157Z"
+    assert info.get("gaia_id") == "15696155517366416778"
+    assert info.get("fullname") == "Nadia Burgess"
+    assert info.get("email") == "nadia@gooten.com"
+    assert info.get("image") == "https://lh3.googleusercontent.com/a-/AOh14GheZe1CyNa3NeJInWAl70qkip4oJ7qLsD8vDy6X=s64"
+    assert info.get("email_username") == "nadia"
 
 
 def test_bitbucket():
@@ -536,7 +549,7 @@ def test_deviantart():
     assert info.get(
         'links') == "['https://www.instagram.com/muse.mercier/']"
     assert info.get('tagline') == 'Nothing worth having is easy...'
-    assert info.get('bio').startswith('Hi my name is Muse Mercier and welcome to my') is True
+    assert info.get('bio').startswith('Hi! My name is Muse Mercier,') is True
     assert info.get('created_at').startswith('2005-06-16')
 
 
@@ -588,6 +601,7 @@ def test_gravatar():
     assert info.get('emails') == "['k.bx@ya.ru']"
     assert info.get('image') == 'https://secure.gravatar.com/avatar/d6ac4c55425d6f9d28db9068dbb49e09'
     assert info.get('links') == "['http://twitter.com/kost_bebix']"
+    assert 'emails_username' not in info
 
 
 def test_pinterest_api():
@@ -985,9 +999,28 @@ def test_trello():
     assert info.get("is_verified") == "True"
 
 
+@pytest.mark.github_failed
 def test_weibo():
     headers = {"cookie": "SUB=_2AkMXyuc_f8NxqwJRmP8SyWPrbo13zAvEieKhlhbkJRMxHRl-123", "cache-control": "no-cache"}
     info = extract(parse('https://weibo.com/clairekuo?is_all=1', headers=headers, timeout=10)[0])
 
     assert info.get("weibo_id") == "1733299783"
     assert info.get("fullname") == "郭靜Claire"
+
+
+def test_icq():
+    info = extract(parse('https://icq.im/CaZaNoVa163')[0])
+
+    assert info.get("fullname") == "Cazanova Haxor"
+    assert info.get("username") == "CaZaNoVa163"
+    assert info.get("image") == "https://ub.icq.net/api/v26/files/avatar/get/?targetNick=CaZaNoVa163&size=1024"
+
+
+def test_pastebin():
+    info = extract(parse('https://pastebin.com/u/GCCXGeneral')[0])
+
+    assert info.get("image") == "https://pastebin.com/cache/img/1/2/20/726408.jpg"
+    assert info.get("location") == "Eastern United States | Contact: GCCXGeneral@gmail.com"
+    assert 'views_count' in info
+    assert 'all_views_count' in info
+    assert info.get("created_at") == "Monday 24th of June 2013 12:25:12 AM CDT"
